import { select, json, geoPath, geoTransverseMercator, zoom, event } from "d3";
import { feature } from "topojson";
const svg = select("svg");

const width = +svg.attr('width');
const height = +svg.attr('height');

const projection = d3.geoTransverseMercator()
  .center([2.5, -38.5])
	.rotate([66, 0])
  .scale((height * 54) / 33)
  .translate([(width / 2), (height / 2)]);
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g')

g.append('path')
  .attr('class', 'sphere')
  .attr('d', pathGenerator({type: 'Sphere'}));

svg.call(zoom().on('zoom', () => {
  g.attr('transform', event.transform)
}));

json('https://raw.githubusercontent.com/shuklaneerajdev/IndiaStateTopojsonFiles/master/Karnataka.topojson')
  .then(data => {
    g.selectAll('#path')
      .data(data.objects['Karnataka'])
      .enter().append('path')
				.attr('class', 'district')
				.attr('d', pathGenerator)
  		.append('title')
  			.text(d => d.properties.Dist_Name);
  });